import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  max,
  line,
  curveBasis
} from 'd3';


//Set the dimensions of the canvas

const margin = {top: 50, right: 50, bottom: 50, left: 50}
  , width = window.innerWidth - margin.left - margin.right 
  , height = window.innerHeight - margin.top - margin.bottom; 

const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;
var colors = ['#FFC300', '#FF5733', '#C70039', '#900C3F']
var types = ["8.0+", "7_7.9", "6_6.9", "5_5.9"]

const	svg1 = select("svg")
		.attr("width", width + margin.left + margin.right)
    .attr("height", height + margin.top + margin.bottom)
    .append("g")
    .attr("transform", "translate(" + margin.left + "," + margin.top + ")");



  const xValue = d => d.year;
  const xAxisLabel = 'Year';
  
  const yValue1 = d => d['5_5.9'];
  const yValue2 = d => d['6_6.9'];
  const yValue3 = d => d['7_7.9'];
  const yValue4 = d => d['8.0+'];
  const circleRadius = 6;
  const yAxisLabel = 'Num of Earthquakes';
   
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth-50]);
  
  const yScale = scaleLinear()
    .domain([0, max(data,yValue1)])
    .range([innerHeight, 0])
    .nice();
  
  const g = svg1.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickPadding(15);
  
  const yAxis = axisLeft(yScale)
    .tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -60)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
    
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 80)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  const lineGenerator1 = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue1(d)))
    .curve(curveBasis)
  	;
  
  const lineGenerator2 = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue2(d)))
    .curve(curveBasis)
    ;
  
  const lineGenerator3 = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue3(d)))
    .curve(curveBasis)
    ;
  
  const lineGenerator4 = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue4(d)))
    .curve(curveBasis)
    ;
  
  g.append('path')
      .attr('class', 'line1')
      .attr('d', lineGenerator1(data));
  
  g.append('path')
    .attr('class', 'line2')
    .attr('d', lineGenerator2(data));
  
  g.append('path')
    .attr('class', 'line3')
    .attr('d', lineGenerator3(data));
  
  g.append('path')
    .attr('class', 'line4')
    .attr('d', lineGenerator4(data));
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
  		.attr('x',innerWidth/6)
      .text('Earthquake Statistics for 2000-2015');
  

	g.append('rect')
  	.attr('y', innerHeight/10)
  	.attr('x',innerWidth-40)
		.attr("width", 40)
    .attr("height", 20)
  	.style("fill", '#FFC300')
  
  g.append('text')
    .attr('y', innerHeight/7)
  	.attr('x',innerWidth+10)
    .text("5_5.9");  
  
  	g.append('rect')
  	.attr('y', innerHeight/5)
  	.attr('x',innerWidth-40)
		.attr("width", 40)
    .attr("height", 20)
  	.style("fill", '#FF5733')
  
  g.append('text')
    .attr('y', innerHeight/4)
  	.attr('x',innerWidth+10)
    .text("6_6.9");  
  
  g.append('rect')
  	.attr('y', innerHeight/3.3)
  	.attr('x',innerWidth-40)
		.attr("width", 40)
    .attr("height", 20)
  	.style("fill", '#C70039')
  
  g.append('text')
    .attr('y', innerHeight/2.9)
  	.attr('x',innerWidth+10)
    .text("7_7.9");  
  
   g.append('rect')
  	.attr('y', innerHeight/2.5)
  	.attr('x',innerWidth-40)
		.attr("width", 40)
    .attr("height", 20)
  	.style("fill", '#900C3F')
  
  g.append('text')
    .attr('y', innerHeight/2.2)
  	.attr('x',innerWidth+10)
    .text("8.0+");  
  
  g.append('text')
    .attr('y', innerHeight+100)
  	.attr('x',innerWidth-800)
    .text("Figure 3a: Example line chart");  
  
  for (const i = 0; i < 4; i++) {
 		svg2.selectAll("circle"+i).data(data).enter().append("circle")  
        .attr("cx", function(d) {return xScale(d["year"])})
        .attr("cy", function(d) {return yScale(d[types[3-i]])})
        .attr("r", function(d) {return rScale(d["Estimated Deaths"])})
        .attr("fill", colors[i]);}
  
});